@@ -31,7 +31,7 @@ impl Install {
 if [ "$HK" = "0" ] || [ "$HK" = "false" ]; then
     exit 0
 fi
-{command} "$@"
+exec {command} "$@"
 "#
             );
             xx::file::write(&hook_file, &hook_content)?;
@@ -39,11 +39,8 @@ fi
             println!("Installed hk hook: .git/hooks/{hook}");
             Result::<(), eyre::Report>::Ok(())
         };
-        if config.hooks.contains_key("pre-commit") {
-            add_hook("pre-commit")?;
-        }
-        if config.hooks.contains_key("pre-push") {
-            add_hook("pre-push")?;
+        for hook in config.hooks.keys() {
+            add_hook(hook)?;
         }
         Ok(())
     }
